# -*- coding: utf-8 -*-
from setuphelpers import *
import string, secrets
import platform
import json
import base64

r"""
Usable WAPT package functions: install(), uninstall(), session_setup(), audit(), update_package()

"""

if platform.system() == 'Windows':
    if uninstall_key_exists('RustDesk'):
        RustDeskBin = makepath(install_location('RustDesk'),'rustdesk.exe')
elif platform.system() == 'Darwin':
    RustDeskBin = "/Applications/RustDesk.app/Contents/MacOS/RustDesk"
else:
    RustDeskBin = "/usr/lib/rustdesk/rustdesk"


def install():
    rustdesk_cfg = open('rustdesk.cfg').read()

    alphabet = string.ascii_letters + string.digits
    rustdesk_pw = ''.join(secrets.choice(alphabet) for i in range(12))

    run_notfatal('"%s" --config %s' % (RustDeskBin,rustdesk_cfg))
    run('"%s" --password %s' % (RustDeskBin,rustdesk_pw ))

    if platform.system() == 'Windows':
        if service_is_running("rustdesk"):
            service_stop("rustdesk")
        service_start("rustdesk")

    elif platform.system() == 'Darwin':
        print('todo')
    else:
        systemd_restart_service('rustdesk')

def audit():
    rustdesk_id = run('"%s" --get-id' % RustDeskBin)
    if rustdesk_id.endswith('\n'):
        rustdesk_id = rustdesk_id.split('\n')[-2]

    alphabet = string.ascii_letters + string.digits
    rustdesk_pw = ''.join(secrets.choice(alphabet) for i in range(12))
    run('"%s" --password %s' % (RustDeskBin, rustdesk_pw))

    WAPT.write_audit_data_if_changed("rustdesk", 'rustdesk-id', rustdesk_id, max_count=365)
    WAPT.write_audit_data_if_changed("rustdesk", 'password_encryption', rsa_encrypted_data_str(rustdesk_pw, WAPT.public_certs_dir), max_count=365)
    
    return "OK"

def encode_rustdesk_config(config):
    rustdesk_list = list(base64.b64encode(json.dumps(config, separators=(',', ':')).encode('utf-8')).decode('utf-8').replace('=',''))
    rustdesk_list.reverse()
    return ''.join(rustdesk_list)

def update_package():
    old_conf = ""
    if isfile('rustdesk.cfg'):
        old_conf = open('rustdesk.cfg').read()
        
    newconf = ""
    if not params.get("install_with_luti", False):
        from waptguihelper import message_dialog, memo_dialog, MB_YESNO, MB_ICONQUESTION
        is_json_config = message_dialog("RUSTDESK Config", "Do you have an json config file ?", MB_YESNO + MB_ICONQUESTION)
        if is_json_config == ID_YES:
            default_conf = {"host": "YOUR_SERVER_IP", "relay": "YOUR_SERVER_IP", "key": "YOUR_PUB_KEY", "api": ""}
            rustdesk_json_config = memo_dialog('RUSTDESK Config', "Please give your rustdesk json config (At you own risk !!)", json.dumps(default_conf, indent=4))
            newconf = encode_rustdesk_config(rustdesk_json_config)
        else: 
            newconf = memo_dialog('RUSTDESK Config', "Please give your rustdesk cfg config that you can retrieved in the 'Audit data' of your host server", old_conf)

        control.package = control.package.replace('-template', '')
        control.save_control_to_wapt()

    with open('rustdesk.cfg', 'w') as f:
        f.write(newconf)